@@ -1986,7 +1986,7 @@ bool SignalWidget::labelProperties(Label *label)
 //    }
 //}
 
-//****************************************************************************
+//***************************************************************************
 //void SignalWidget::saveBlocks (int bit)
 //{
 //    if (signalmanage) {
@@ -2487,5 +2487,7 @@ void SignalWidget::dragMoveEvent(QDragMoveEvent* event)
     } else event->ignore(rect());
 }
 
+//***************************************************************************
+#include "SignalWidget.moc"
 //***************************************************************************
 //***************************************************************************
