@@ -167,6 +167,7 @@ void MenuItem::setText(const QString &text)
     }
 }
 
+//***************************************************************************
+#include "MenuItem.moc"
 //*****************************************************************************
 //*****************************************************************************
-/* end of libgui/MenuItem.cpp */
