@@ -255,6 +255,7 @@ MenuManager::~MenuManager()
     if (m_menu_root) delete m_menu_root;
 }
 
+//***************************************************************************
+#include "MenuManager.moc"
 //***************************************************************************
 //***************************************************************************
-/* end of MenuManager.cpp */
