@@ -564,4 +564,7 @@ bool MenuNode::specialCommand(const QString &command)
     return false;
 }
 
-/* end of MenuNode.cpp */
+//***************************************************************************
+#include "MenuNode.moc"
+//***************************************************************************
+//***************************************************************************
