@@ -20,12 +20,13 @@
 
 #include "config.h"
 #include <string.h>
-#include <qglobal.h> // for warning()
-#include <qvector.h>
+#include <qglobal.h> // for qWarning()
+#include <qptrvector.h>
 
 #include <arts/artsflow.h>
 #include <arts/connect.h>
 #include <arts/objectmanager.h>
+#include <arts/dynamicrequest.h>
 
 #include "libkwave/ArtsMultiTrackFilter.h"
 
@@ -36,6 +37,7 @@ public:
     /**
      * Constructor. Creates all filter objects.
      * @param tracks the number of tracks
+     * @param name the name of the aRts class
      */
     ArtsNativeMultiTrackFilter(unsigned int tracks, const std::string name)
 	:m_count(tracks), m_filter(tracks)
@@ -54,7 +56,7 @@ public:
 	    }
 	
 	    if (!m_filter[i]) {
-		warning("ArtsMultiTrackFilter: filter creation failed!!!");
+		qWarning("ArtsMultiTrackFilter: filter creation failed!!!");
 		m_count = i;
 		break;
 	    }
@@ -125,11 +127,44 @@ public:
 	const std::string &input_name = "input",
 	const std::string &output_name = "output")
     {
-	for (unsigned i=0; i < m_count; ++i)
+	for (unsigned int i=0; i < m_count; ++i)
 	    Arts::connect(*(m_filter[i]), output_name,
 	                  *(sink[i]),     input_name);
     };
 
+    /**
+     * Set all input of the filters to the same constant value.
+     * @param input_name name of the input of the sinks
+     * @param value float value to be set
+     */
+    virtual void setValue(
+	const std::string &input_name,
+	const float value)
+    {
+	for (unsigned int i=0; i < m_count; ++i)
+	    Arts::setValue(*(m_filter[i]), input_name, value);
+    };
+
+    /**
+     * Set all attributes of the filters to the same constant value.
+     * @param attribute name of the attribute to set
+     * @param value float value to be set
+     */
+    virtual void setAttribute(
+	const std::string &attribute,
+	const float value)
+    {
+	std::string command;
+	command = "_set_";
+	command += attribute;
+	for (unsigned int i=0; i < m_count; ++i) {
+	    Arts::Object &object(*(m_filter[i]));
+	    Arts::DynamicRequest(object).method(
+	        command).param(value).invoke();
+	}
+    };
+ 
+
     /** Starts all filters. */
     virtual void start() {
 	for (unsigned int i=0; i < m_count; ++i) m_filter[i]->start();
@@ -146,7 +181,7 @@ private:
     unsigned int m_count;
 
     /** list of the filters */
-    QVector<Arts::SynthModule> m_filter;
+    QPtrVector<Arts::SynthModule> m_filter;
 
 };
 
