@@ -17,11 +17,13 @@
 
 #include <Decoder.h>
 
-/***************************************************************************/
+//***************************************************************************
 Decoder::Decoder()
     :QObject(), CodecBase()
 {
 }
 
-/***************************************************************************/
-/***************************************************************************/
+//***************************************************************************
+#include "Decoder.moc"
+//***************************************************************************
+//***************************************************************************
