@@ -23,6 +23,7 @@
 #include <qstring.h>
 #include <qvariant.h>
 #include "libkwave/TypesMap.h"
+#include "libkwave/LabelList.h"
 
 /**
  * @enum FileProperty
@@ -53,6 +54,7 @@ typedef enum {
     INF_GENRE,               /**< genre */
     INF_ISRC,                /**< International Standard Recording Code */
     INF_KEYWORDS,            /**< keywords */
+    INF_LABELS,              /**< labels/markers */
     INF_LICENSE,             /**< license information */
     INF_MEDIUM,              /**< medium */
     INF_MIMETYPE,            /**< mime type of the file format */
@@ -77,6 +79,12 @@ typedef enum {
     INF_VERSION              /**< version/remix */
 } FileProperty;
 
+/** increment operator for FileProperty */
+static inline FileProperty operator ++ (FileProperty &prop) {
+    prop = static_cast<FileProperty>(static_cast<unsigned int>(prop) + 1);
+    return prop;
+};
+
 /**
  * @class FileInfo
  * Holds various properties of a file.
@@ -135,6 +143,12 @@ public:
     /** Sets the number of tracks */
     inline void setTracks(unsigned int tracks) { m_tracks = tracks; };
 
+    /** Returs the list of labels. @note can be modified! */
+    inline LabelList &labels() { return m_labels; };
+
+    /** Returs the list of labels. @note cannot be modified! */
+    inline const LabelList &labels() const { return m_labels; };
+
     /** Returns true if the given property exists */
     inline bool contains(const FileProperty property) const {
 	return m_properties.contains(property);
@@ -187,6 +201,9 @@ public:
 	return m_properties;
     };
 
+    /** Returns a list of all known non-standard properties */
+    QValueList<FileProperty> allKnownProperties();
+
     /** Clears the list of all properties. */
     void clear();
 
@@ -207,6 +224,9 @@ private:
     /** number of tracks */
     unsigned int m_tracks;
 
+    /** list of labels */
+    LabelList m_labels;
+
     /** list of properties */
     QMap<FileProperty, QVariant> m_properties;
 
@@ -216,7 +236,11 @@ private:
     class PropertyTypesMap: public TypesMap<FileProperty, int>
     {
     public:
-        virtual void fill();
+	/** fills the list with */
+	virtual void fill();
+
+	/** returns a list of all properties */
+	virtual QValueList<FileProperty> all();
     };
 
     /** map with properties and their names and descriptions */
