@@ -432,6 +432,7 @@ void KwavePlugin::emitCommand(const QString &command)
     manager().enqueueCommand(command);
 }
 
+//***************************************************************************
+#include "KwavePlugin.moc"
 //***************************************************************************
 //***************************************************************************
-/* end of libgui/KwavePlugin.cpp */
