@@ -31,6 +31,9 @@ public:
      */
     Label(unsigned int position, const QString &name);
 
+    /** Copy constructor */
+    Label(const Label &source);
+
     /** destructor */
     virtual ~Label();
 
