@@ -31,6 +31,23 @@ public:
     /** Destructor */
     virtual ~LabelList();
 
+    /** Copy everything from another LabelList */
+    void copy(const LabelList &source);
+
+    /** Return true if the list is equal to another list */
+    bool equals(const LabelList &other) const;
+
+    /** Assignment operator */
+    inline LabelList & operator = (const LabelList &source) {
+	copy(source);
+	return *this;
+    };
+
+    /** Compare operator */
+    inline bool operator == (const LabelList &other) const {
+	return equals(other);
+    }
+
 protected:
     /**
      * compare two labels, for sorting
@@ -39,4 +56,7 @@ protected:
     virtual int compareItems(QPtrCollection::Item a, QPtrCollection::Item b);
 };
 
+/** Iterator for the list of labels */
+typedef QPtrListIterator<Label> LabelListIterator;
+
 #endif /* _LABEL_LIST_H_ */
