@@ -133,39 +133,6 @@ signals:
      */
      void sigSelectionChanged();
 
-private slots:
-
-    /**
-     * Connected to each stripe's sigSamplesInserted.
-     * @param src source stripe of the signal (*this)
-     * @param offset position from which the data was inserted
-     * @param length number of samples inserted
-     * @see Stripe::sigSamplesInserted
-     * @internal
-     */
-    void slotSamplesInserted(Stripe &src, unsigned int offset,
-                             unsigned int length);
-
-    /**
-     * Connected to each stripe's sigSamplesDeleted.
-     * @param src source stripe of the signal
-     * @param offset position from which the data was removed
-     * @param length number of samples deleted
-     * @see Stripe::sigSamplesDeleted
-     * @internal
-     */
-    void slotSamplesDeleted(Stripe &src, unsigned int offset,
-                            unsigned int length);
-
-    /**
-     * Connected to each stripe's sigSamplesModified
-     * @param offset position from which the data was modified
-     * @param length number of samples modified
-     * @internal
-     */
-    void slotSamplesModified(unsigned int offset,
-                             unsigned int length);
-
 private:
     /**
      * Returns the current length of the stripe in samples. This
@@ -199,13 +166,6 @@ private:
      */
     void moveRight(unsigned int offset, unsigned int shift);
 
-    /**
-     * Connect all signals of the stripe to us
-     *
-     * @param s pointer to the stripe to be connected
-     */
-    void connectStripe(Stripe *s);
-
     /**
      * Append a new stripe with a given length.
      *
