@@ -19,9 +19,8 @@
 #define _SHARED_LOCK_H_
 
 #include "config.h"
-#include "mt/TSS_Object.h"
-#include "mt/Mutex.h"
-#include "mt/ThreadCondition.h"
+#include <qmutex.h>
+#include <qwaitcondition.h>
 
 /**
  * @class SharedLock
@@ -36,7 +35,7 @@
  * @see SharedLockGuard
  * @see Mutex
  */
-class SharedLock: public TSS_Object
+class SharedLock
 {
 public:
 
@@ -95,13 +94,13 @@ private:
     unsigned int m_shared_count;
 
     /** Mutex for exclusively locking and some internal critical regions */
-    Mutex m_lock_exclusive;
+    QMutex m_lock_exclusive;
 
     /**
-     * ThreadCondition for synchronization of threads that are waiting
+     * QWaitCondition for synchronization of threads that are waiting
      * for shared or exclusive access.
      */
-    ThreadCondition m_lock_changed;
+    QWaitCondition m_lock_changed;
 
 };
 
