@@ -50,5 +50,7 @@ void OggCodecPlugin::load(QStringList &/* params */)
     if (m_decoder) CodecManager::registerDecoder(*m_decoder);
 }
 
-/***************************************************************************/
-/***************************************************************************/
+//***************************************************************************
+#include "OggCodecPlugin.moc"
+//***************************************************************************
+//***************************************************************************
