@@ -51,6 +51,24 @@ public:
     /** Returns a list of supported file properties */
     virtual QValueList<FileProperty> supportedProperties();
 
+private:
+
+    /**
+     * write the INFO chunk with all known file properties
+     *
+     * @param dst file or other source to receive a stream of bytes
+     * @param info information about the file to be saved
+     */
+    void writeInfoChunk(QIODevice &dst, FileInfo &info);
+
+    /**
+     * write the 'cue list' and the label names (if any)
+     *
+     * @param dst file or other source to receive a stream of bytes
+     * @param info information about the file to be saved, including labels
+     */
+    void writeLabels(QIODevice &dst, FileInfo &info);
+
 private:
 
     /** map for translating chunk names to FileInfo properties */
